==> mysite-5.x-2.11.tar.gz: mysite/plugins/layouts/left.php <==
<?php
// $Id: left.php,v 1.4 2007/08/26 19:38:51 agentken Exp $

/**
 * @file
 * A two-column page layout file for MySite with one narrow rail.  Optional.
 */

/**
 * Implements theme_mysite_hook_layout()
 *
 * @ingroup themes
 */
function theme_mysite_left_layout($content) {
  // break the array into pieces
  $owner = $content['owner'];
  $mysite = $content['mysite'];
  $columns = mysite_layout_left();
  $data = mysite_prepare_columns($mysite, $content['data'], $columns['count']);
  $header = $content['header'];
  // print the header message, if present
  if (isset($header)) {
    $output = '<div class="messages">'.  $header .'</div>';
  }
  // ajax-generated message class
  $output .= '<div class="mysite-ajax"></div>';  
  // cycle through the data sets and make columns
  foreach ($data as $col => $set) {
    if ($col == 0) {
      $output .= '<div class="mysite-sortable mysite-single-width" id="mysite-sort'. $col .'">';  
    }
    else {
      $output .= '<div class="mysite-sortable mysite-quadruple-width" id="mysite-sort'. $col .'">';      
    }
    foreach ($set as $key => $value) {
    if ($value['mid'] && !$value['locked']) {
        $output .= '<div class="mysite-group collapsible sortable-item" id="m'. $value['mid'] .'">';
      }
      else {
        $output .= '<div class="mysite-group collapsible">';
      }
       $output .= '<span class="mysite-header">'. $value['title'] .'</span>';
       $output .= '<div class="mysite-content">';
      if (!empty($value['output'])) {
        if (!empty($value['output']['image'])) {
          $output .= $value['output']['image'];
        } 
        $output .= theme('mysite_'. $value['format'] .'_item', $value['output']['items']);
      }
      else {
        $output .= t('<p>No content found.</p>');
      }
      $output .= '</div>';
      $output .= '<div class="mysite-footer">';
      if (!empty($value['output']['base'])) {
        $output .= '<div class="mysite-footer-left">'. l(t('Read more'), $value['output']['base']) .'</div>';
      }
      $output .= ' <div class="mysite-footer-right">'. $value['actions'] .'</div> ';
      $output .= '</div>';    
      $output .= '</div>';   
    }  
    $output .= '</div>';
  }
  print theme('page', $output, variable_get('mysite_fullscreen', 1));
  return;
}

/**
 * Implements mysite_layout_hook()
 */
function mysite_layout_left() {
  $data = array();
  $data['regions'] = array('0' => t('Sidebar'), '1' => t('Main'));
  $data['count'] = count($data['regions']);
  $data['name'] = t('Left Sidebar');
  $data['description'] = t('A large main area with left sidebar.');  
  $data['image'] = 'left.png';
  return $data;
}

==> mysite-5.x-2.16.tar.gz: mysite/plugins/layouts/left.php <==
<?php
// $Id: left.php,v 1.4.2.1 2007/10/24 01:33:34 agentken Exp $

/**
 * @file
 * A two-column page layout file for MySite with one narrow rail.  Optional.
 */

/**
 * Implements theme_mysite_hook_layout()
 *
 * @ingroup themes
 */
function theme_mysite_left_layout($content) {
  // break the array into pieces
  $owner = $content['owner'];
  $mysite = $content['mysite'];
  $columns = mysite_layout_left();
  $data = mysite_prepare_columns($mysite, $content['data'], $columns['count']);
  $header = $content['header'];
  // print the header message, if present
  if (isset($header)) {
    $output = '<div class="messages">'.  $header .'</div>';
  }
  // ajax-generated message class
  $output .= '<div class="mysite-ajax"></div>';  
  // cycle through the data sets and make columns
  foreach ($data as $col => $set) {
    if ($col == 0) {
      $output .= '<div class="mysite-sortable mysite-single-width" id="mysite-sort'. $col .'">';  
    }
    else {
      $output .= '<div class="mysite-sortable mysite-quadruple-width" id="mysite-sort'. $col .'">';      
    }
    foreach ($set as $key => $value) {
    if ($value['mid'] && !$value['locked']) {
        $output .= '<div class="mysite-group collapsible sortable-item" id="m'. $value['mid'] .'">';
      }
      else {
        $output .= '<div class="mysite-group collapsible">';
      }
       $output .= '<span class="mysite-header">'. $value['title'] .'</span>';
       $output .= '<div class="mysite-content">';
      if (!empty($value['output'])) {
        if (!empty($value['output']['image'])) {
          $output .= $value['output']['image'];
        } 
        $output .= theme('mysite_'. $value['format'] .'_item', $value['output']['items']);
      }
      else {
        $output .= t('<p>No content found.</p>');
      }
      $output .= '</div>';
      $output .= '<div class="mysite-footer">';
      if (!empty($value['output']['base'])) {
        $output .= '<div class="mysite-footer-left">'. l(t('Read more'), $value['output']['base']) .'</div>';
      }
      $output .= ' <div class="mysite-footer-right">'. $value['actions'] .'</div> ';
      $output .= '</div>';    
      $output .= '</div>';   
    }  
    $output .= '</div>';
  }
  print theme('page', $output, variable_get('mysite_fullscreen', 1));
  return;
}

/**
 * Implements mysite_layout_hook()
 */
function mysite_layout_left() {
  $data = array();
  $data['regions'] = array('0' => t('Sidebar'), '1' => t('Main'));
  $data['count'] = count($data['regions']);
  $data['name'] = t('Left sidebar');
  $data['description'] = t('A large main area with left sidebar.');  
  $data['image'] = 'left.png';
  return $data;
}
